% Computes value of a polynomial and its derivative at a point
% using Horner's algorithm twice.
%
% Inputs
%  p 	vector of polynomial coefficients, from highest to lowest degree
%  z0   evaluation point
%
% Outputs
%  alpha  p(z0)
%  beta   p'(z0)

function [alpha,beta] = hornernm(p,z0)

 % TO BE COMPLETED
